.. SPDX-FileCopyrightText: 2023-2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

Table of Contents
=================

.. toctree::
   :caption: Home

   index

.. toctree::
   :caption: Documentation

   installation
   getting-started
   contributing
   release-notes
   reference

.. toctree::
   :caption: External Links

   Git Repository <https://git.sysrq.in/gentle/>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
